@@ -1,9 +1,12 @@
 from nose.exc import SkipTest
 from nose.tools import *
 from nose.twistedtools import *
+try:    
+    from twisted.internet.defer import Deferred
+    from twisted.internet.error import DNSLookupError
+except ImportError:
+    raise SkipTest('twisted not available; skipping')
 
-from twisted.internet.defer import Deferred
-from twisted.internet.error import DNSLookupError
 
 
 def teardown():
